@@ -6,6 +6,8 @@
 include_once("auth.php");
 db_connect($db_host, $db_user, $db_pass);
 
+$indexcode = str_replace(chr(174), '&reg;', $indexcode);
+$indexcode = str_replace(chr(169), '&copy;', $indexcode);
 $indexcode = addslashes($indexcode);
 $indexfile = addslashes($indexfile);
 
