@@ -6,7 +6,7 @@
 ?>
 <html>
 <head>
-<title>Confixx Professional</title>
+<title>Parallels Confixx</title>
 </head>
   <frameset cols ="230,*" border=0 frameborder=0 framespacing=0>
     <frame name=menu             src="menu.php?num=1" marginheight=0 marginwidth=0 scrolling=auto noresize frameborder=0>
