@@ -1100,7 +1100,7 @@ class User extends Actor {
 				
 				$loFlds = new SQLFieldSet( new SQLField( 'domain', $ls_Domain, 'C' ),
 																	 new SQLField( 'zonefile', $ls_Zonefile, 'C' ),
-																	 new SQLField( 'lastchange', $this->ms_Timestamp),
+																	 new SQLField( 'lastchange', date('Ymd')."01"),
 																	 new SQLField( 'neu', 1 ),
 																	 new SQLField( 'anbieter', $pa_Reseller['anbieter'], 'C' ),
 																	 new SQLField( 'kunde', $this->ms_Name, 'C'),
@@ -1108,7 +1108,6 @@ class User extends Actor {
 																	 );
 
 				list($lcFields,$lcVals) = $loFlds->getSQLInsert();
-
 				$lcSQL = "INSERT INTO dns ( $lcFields ) VALUES ( $lcVals )";
 				db_query( $lcSQL ); 
 
