@@ -9,7 +9,7 @@
  
 // in index.php
 class tGuiPP_MainFrameSet {
-	var $l_product_name = 'Confixx Professional';	
+	var $l_product_name = 'Parallels Confixx';	
 
 	var $head_icon_id  = ''; 
 	var $head_text = ''; 
@@ -232,7 +232,7 @@ function ShowConHelp(conhelp_string)
 
 document.write('<frameset cols="200,*" border=0 framespacing=0 frameborder=0>'+
 							 '<frame src="<?=$this->menu_url?>" name="leftFrame" frameborder="0" border="0" noresize="noresize"'+ieAddScroll+ieAddResize+'>'+
-							 '<frameset rows="53,*" border="0" frameborder="0" framespacing="0" noresize="noresize">'+
+							 '<frameset rows="49,*" border="0" frameborder="0" framespacing="0" noresize="noresize">'+
 							 '<frame src="ver_pp_frame_top.php" name="topFrame" frameborder=0 border=0 framespacing=0 marginheight=0 marginwidth=0 scrolling="No" noresize>'+
 							 '<frame src="ver_pp_frame_main.php<?=$frame_main_args?>" name="contentFrame" frameborder="0" border="0" scrolling="no" onresize="self.contentFrame.setFramesSizes();"/>'+
 							 '</frameset></frameset>');
