@@ -7,7 +7,7 @@ include("auth.php");
 ?>
 <html>
 <head>
-<title>Confixx Professional</title>
+<title>Parallels Confixx</title>
 </head>
 <script>
 top.fraTitle.location.href = 'title_se.php';
