@@ -89,9 +89,9 @@ $lang_text['alsr_cell_saveanyway'] = 'save anyway';
 $lang_text['alsr_cell_select'] = 'select';
 $lang_text['alsr_cell_testconn'] = 'Test connection';
 $lang_text['alsr_cell_user'] = 'db username';
-$lang_text['alsr_descr1'] = 'Here you can administrate your list of Confixx Professional servers. You can add, edit or remove a single server. To work with one server choose <b>select</b>.';
+$lang_text['alsr_descr1'] = 'Here you can administrate your list of Parallels Confixx servers. You can add, edit or remove a single server. To work with one server choose <b>select</b>.';
 $lang_text['alsr_descr2'] = 'Click <a href="$VAR[0]">here</a> to add a new server.';
-$lang_text['alsr_descr3'] = 'Click here to select the Confixx Professional server on which Confixx Business is running';
+$lang_text['alsr_descr3'] = 'Click here to select the Parallels Confixx server on which Confixx Business is running';
 $lang_text['alsr_title1'] = 'Confixx server list';
 $lang_text['alst_cell_atdomains'] = 'Number of at-domains';
 $lang_text['alst_cell_countdu'] = 'Determine used storage space';
