@@ -451,6 +451,7 @@ $lang_text['m_login'] = 'Log on again';
 $lang_text['m_maillist'] = 'Mailing lists';
 $lang_text['m_message'] = 'Message';
 $lang_text['m_move_to'] = 'Move to $VAR[0]';
+$lang_text['m_move_to_error0'] = 'Error: the Folder where the email will be moved is not selected';
 $lang_text['m_overview'] = 'Overview';
 $lang_text['m_postfach'] = 'Message list';
 $lang_text['m_restore'] = 'Restore';
@@ -795,7 +796,7 @@ $lang_text['topwae2_error4'] = 'The new directory has already been furnished wit
 $lang_text['topwae2_error5'] = 'The data have been changed.';
 $lang_text['topwae2_errortitle'] = 'Notice:';
 $lang_text['topwae_btn_change'] = 'Apply';
-$lang_text['topwae_btn_del'] = 'Remove all users and passwords';
+$lang_text['topwae_btn_del'] = 'Remove all users';
 $lang_text['topwae_btn_new'] = 'Create';
 $lang_text['topwae_cell_action'] = 'Action';
 $lang_text['topwae_cell_area'] = 'Section:';
