@@ -1596,6 +1596,10 @@ sub fill_columns {
   $dbh->do( "UPDATE allgemein SET checknewversion = 12 WHERE checknewversion = 0 AND server_id='$ServerID'");
   $dbh->do( "UPDATE zeiten SET checknewversion = 12 WHERE checknewversion = 0 AND server_id='$ServerID'");
   ## /3.0.4
+  
+  ## 3.3.2
+  $dbh->do( "UPDATE httpd_states SET data='<Directory \"##user_home##/##user##/html\">\r\nAllowOverride All\r\nOptions +FollowSymlinks\r\n</Directory>' WHERE id=6");
+  ## /3.3.2   
 }
 
 #
