@@ -53,13 +53,14 @@ use Modules::System;
 
 use strict;
 
-our ($newVersion,$newLangfileversion);
+our ($newVersion,$newBuild,$newLangfileversion);
 
 
 
 # it is replaced during make
 
-$newVersion = '3.3.1';
+$newVersion = '3.3.3';
+$newBuild = '9';
 $newLangfileversion = '3.1.0';
 
 
@@ -472,6 +473,7 @@ if($secondaryServer){
 }
 
 $version = $newVersion;
+$build = $newBuild;
 $langfileversion = $newLangfileversion;
 
 unless( $ServerID ){
@@ -976,7 +978,7 @@ sub fixSkinVersion{
 
 sub print_congratulations() {
 
-	my $width = 56;
+	my $width = 62;
 	my $text = <<CONGRAT;
 The upgrade process was successfully completed.
 Your Confixx installation is upgraded to $newVersion.
