@@ -58,7 +58,8 @@ $language = 'en';
 
 # it is replaced during make
 
-$version = '3.3.1';
+$version = '3.3.3';
+$build = '9';
 $langfileversion = '3.1.0';
 
 
@@ -196,6 +197,7 @@ sub GetUserInfo{
   my @maildrops = ('/var/spool/mail/USER', 'HOMEDIR/Mailbox', 'HOMEDIR/Maildir/');
   my @httpds = ('apache1.3', 'apache2.0');
   my $default_httpd_conf = '/etc/httpd/conf/httpd.conf';
+  my $suphp_no_calc_apache_files_for_users_disk_usage = '1';
 
 	foreach my $path ( '/usr/local/apache/conf/httpd.conf',
 										 '/usr/local/etc/apache/httpd.conf',
@@ -1129,6 +1131,7 @@ sub writeTmpFile{
 # allgemein
 \$OSTYPE = '$OSTYPE';
 \$version = '$version';
+\$build = '$build';
 \$language = '$language';
 \$langfileversion = '$langfileversion';  
 \$user_homeDir = '$user_homeDir';
@@ -1197,6 +1200,7 @@ sub writeTmpFile{
 \$php_ini_dir = '$php_ini_dir';
 \$php_ini_file = '$php_ini_file';
 \$php_special = '$php_special';
+\$suphp_no_calc_apache_files_for_users_disk_usage = '$suphp_no_calc_apache_files_for_users_disk_usage';
 
 #scponly
 \$scponly_shell = '$scponly_shell';
