@@ -10,6 +10,8 @@ global $DEBUG;
 //$DEBUG=1;
 
 $loUser = new SQLString($PHP_AUTH_USER);
+$indexcode = str_replace(chr(174), '&reg;', $indexcode);
+$indexcode = str_replace(chr(169), '&copy;', $indexcode);
 
 safe_query2( "UPDATE anbieter SET indexcode = ?, indexfile = ?".
 						 " WHERE anbieter = ? AND server_id='$ServerID'", new SQLString($indexcode),
