@@ -923,10 +923,10 @@ sub etc_shells{
 
 sub show_congratulations() {
 
-    my $PRODNAME_BIG	= "Confixx Professional";
+    my $PRODNAME_BIG	= "Parallels Confixx";
     my $passwd		= 'confixx';
-    my $product_bs	= 'SWsoft sales';
-    my $sales_email	= 'sales@sw-soft.com';
+    my $product_bs	= 'Parallels sales';
+    my $sales_email	= 'sales@parallels.com';
 
     print << "EOF";
                              Congratulations!
