@@ -30,6 +30,7 @@ $lang_text['anne_cell_durationitem1'] = 'Woche(n)';
 $lang_text['anne_cell_durationitem2'] = 'Monat(e)';
 $lang_text['anne_cell_durationitem3'] = 'Jahr(e)';
 $lang_text['confixx_easy'] = 'Confixx Easy';
+$lang_text['confixx_page'] = 'Hier entstehen die Internet-Seiten des Confixx Benutzers';
 $lang_text['current_path'] = 'Aktueller Pfad';
 $lang_text['errtype_any'] = 'Alle:';
 $lang_text['errtype_error'] = 'Fehler:';
@@ -50,7 +51,7 @@ $lang_text['form_get_password'] = 'Passwort holen';
 $lang_text['form_login'] = 'Einloggen';
 $lang_text['form_logintext'] = 'Geben Sie Ihren Login und Ihr Passwort ein und klicken Sie dann auf "Einloggen".';
 $lang_text['form_password'] = 'Passwort:';
-$lang_text['form_please_login'] = 'Bitte Einloggen';
+$lang_text['form_please_login'] = 'Einloggen ins Parallels Confixx';
 $lang_text['form_sent_pwd'] = 'Passwort via E-Mail verschicken.';
 $lang_text['form_unexpand'] = 'Erweiterte Optionen verbergen';
 $lang_text['form_username'] = 'Login:';
@@ -58,7 +59,7 @@ $lang_text['fp_incorrect_field'] = 'Feld <b>$VAR[0]</b> wurde inkorrekt ausgefll
 $lang_text['fp_incorrect_fields'] = 'Einige Felder wurden inkorrekt ausgefllt. Bitte versuchen Sie es erneut.';
 $lang_text['fp_required_fields'] = 'erforderliche Felder.';
 $lang_text['go_to_confixx'] = 'Zur Confixx-Homepage';
-$lang_text['go_to_swsoft'] = 'Zur SWsoft-Homepage';
+$lang_text['go_to_swsoft'] = 'Zur Parallels-Homepage';
 $lang_text['help_frame__header'] = 'Hilfe';
 $lang_text['help_frame__hide'] = 'Hilfe ausblenden';
 $lang_text['help_frame__show'] = 'Hilfe einblenden';
