@@ -608,7 +608,7 @@ sub CreateAdminDefaults{
 								'number' => 0,
 								'uid' => 0,
 								'passwort' => undef,
-								'longpw' => undef,
+								'longpw' => [ '!'.$confixx_admin_pw_crypt, 'C' ],
 								'anbieter' => undef,
 								'maxpop' => undef,
 								'maxkb' => undef,
@@ -626,7 +626,7 @@ sub CreateAdminDefaults{
 								'shell' => 1,
 								'statistik' => 1,
 								'statistikpasswort' => [ '', 'C' ],
-								'statistiklongpw' => [ $confixx_admin_pw_crypt, 'C' ],
+								'statistiklongpw' => [ '!'.$confixx_admin_pw_crypt, 'C' ],
 								'pwschutz' => 1,
 								'fehlerseiten' =>  1,
 								'webftp' => undef,
